defmodule Textos.Content do
  @moduledoc """
  The Content context.
  """

  import Ecto.Query, warn: false
  alias Textos.Repo

  alias Textos.Content.Media

  @doc """
  Returns the list of media.

  ## Examples

      iex> list_media()
      [%Media{}, ...]

  """
  def list_media do
    Repo.all(Media)
  end

  @doc """
  Gets a single media.

  Raises `Ecto.NoResultsError` if the Media does not exist.

  ## Examples

      iex> get_media!(123)
      %Media{}

      iex> get_media!(456)
      ** (Ecto.NoResultsError)

  """
  def get_media!(id) do
    Media
    |> Repo.get!(id)
    |> Repo.preload(:subtitles)
    |> Repo.preload(:translations)
    |> Repo.preload(:transcriptions)
  end

  @doc """
  Creates a media.

  ## Examples

      iex> create_media(%{field: value})
      {:ok, %Media{}}

      iex> create_media(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_media(attrs \\ %{}) do
    %Media{}
    |> Media.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a media.

  ## Examples

      iex> update_media(media, %{field: new_value})
      {:ok, %Media{}}

      iex> update_media(media, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_media(%Media{} = media, attrs) do
    media
    |> Media.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a media.

  ## Examples

      iex> delete_media(media)
      {:ok, %Media{}}

      iex> delete_media(media)
      {:error, %Ecto.Changeset{}}

  """
  def delete_media(%Media{} = media) do
    Repo.delete(media)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking media changes.

  ## Examples

      iex> change_media(media)
      %Ecto.Changeset{data: %Media{}}

  """
  def change_media(%Media{} = media, attrs \\ %{}) do
    Media.changeset(media, attrs)
  end

  alias Textos.Content.Subtitle

  @doc """
  Returns the list of subtitles.

  ## Examples

      iex> list_subtitles()
      [%Subtitle{}, ...]

  """
  def list_subtitles do
    Repo.all(Subtitle)
  end

  @doc """
  Gets a single subtitle.

  Raises `Ecto.NoResultsError` if the Subtitle does not exist.

  ## Examples

      iex> get_subtitle!(123)
      %Subtitle{}

      iex> get_subtitle!(456)
      ** (Ecto.NoResultsError)

  """
  def get_subtitle!(id), do: Repo.get!(Subtitle, id)

  @doc """
  Creates a subtitle.

  ## Examples

      iex> create_subtitle(%{field: value})
      {:ok, %Subtitle{}}

      iex> create_subtitle(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_subtitle(attrs \\ %{}) do
    %Subtitle{}
    |> Subtitle.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a subtitle.

  ## Examples

      iex> update_subtitle(subtitle, %{field: new_value})
      {:ok, %Subtitle{}}

      iex> update_subtitle(subtitle, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_subtitle(%Subtitle{} = subtitle, attrs) do
    subtitle
    |> Subtitle.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a subtitle.

  ## Examples

      iex> delete_subtitle(subtitle)
      {:ok, %Subtitle{}}

      iex> delete_subtitle(subtitle)
      {:error, %Ecto.Changeset{}}

  """
  def delete_subtitle(%Subtitle{} = subtitle) do
    Repo.delete(subtitle)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking subtitle changes.

  ## Examples

      iex> change_subtitle(subtitle)
      %Ecto.Changeset{data: %Subtitle{}}

  """
  def change_subtitle(%Subtitle{} = subtitle, attrs \\ %{}) do
    Subtitle.changeset(subtitle, attrs)
  end

  alias Textos.Content.Transcription

  @doc """
  Returns the list of transcriptions.

  ## Examples

      iex> list_transcriptions()
      [%Transcription{}, ...]

  """
  def list_transcriptions do
    Repo.all(Transcription)
  end

  @doc """
  Gets a single transcription.

  Raises `Ecto.NoResultsError` if the Transcription does not exist.

  ## Examples

      iex> get_transcription!(123)
      %Transcription{}

      iex> get_transcription!(456)
      ** (Ecto.NoResultsError)

  """
  def get_transcription!(id), do: Repo.get!(Transcription, id)

  @doc """
  Creates a transcription.

  ## Examples

      iex> create_transcription(%{field: value})
      {:ok, %Transcription{}}

      iex> create_transcription(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_transcription(attrs \\ %{}) do
    %Transcription{}
    |> Transcription.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a transcription.

  ## Examples

      iex> update_transcription(transcription, %{field: new_value})
      {:ok, %Transcription{}}

      iex> update_transcription(transcription, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_transcription(%Transcription{} = transcription, attrs) do
    transcription
    |> Transcription.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a transcription.

  ## Examples

      iex> delete_transcription(transcription)
      {:ok, %Transcription{}}

      iex> delete_transcription(transcription)
      {:error, %Ecto.Changeset{}}

  """
  def delete_transcription(%Transcription{} = transcription) do
    Repo.delete(transcription)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking transcription changes.

  ## Examples

      iex> change_transcription(transcription)
      %Ecto.Changeset{data: %Transcription{}}

  """
  def change_transcription(%Transcription{} = transcription, attrs \\ %{}) do
    Transcription.changeset(transcription, attrs)
  end

  alias Textos.Content.Translation

  @doc """
  Returns the list of translations.

  ## Examples

      iex> list_translations()
      [%Translation{}, ...]

  """
  def list_translations do
    Repo.all(Translation)
  end

  @doc """
  Gets a single translation.

  Raises `Ecto.NoResultsError` if the Translation does not exist.

  ## Examples

      iex> get_translation!(123)
      %Translation{}

      iex> get_translation!(456)
      ** (Ecto.NoResultsError)

  """
  def get_translation!(id), do: Repo.get!(Translation, id)

  @doc """
  Creates a translation.

  ## Examples

      iex> create_translation(%{field: value})
      {:ok, %Translation{}}

      iex> create_translation(%{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def create_translation(attrs \\ %{}) do
    %Translation{}
    |> Translation.changeset(attrs)
    |> Repo.insert()
  end

  @doc """
  Updates a translation.

  ## Examples

      iex> update_translation(translation, %{field: new_value})
      {:ok, %Translation{}}

      iex> update_translation(translation, %{field: bad_value})
      {:error, %Ecto.Changeset{}}

  """
  def update_translation(%Translation{} = translation, attrs) do
    translation
    |> Translation.changeset(attrs)
    |> Repo.update()
  end

  @doc """
  Deletes a translation.

  ## Examples

      iex> delete_translation(translation)
      {:ok, %Translation{}}

      iex> delete_translation(translation)
      {:error, %Ecto.Changeset{}}

  """
  def delete_translation(%Translation{} = translation) do
    Repo.delete(translation)
  end

  @doc """
  Returns an `%Ecto.Changeset{}` for tracking translation changes.

  ## Examples

      iex> change_translation(translation)
      %Ecto.Changeset{data: %Translation{}}

  """
  def change_translation(%Translation{} = translation, attrs \\ %{}) do
    Translation.changeset(translation, attrs)
  end
end
