defmodule Textos.ContentTest do
  use Textos.DataCase

  alias Textos.Content

  describe "media" do
    alias Textos.Content.Media

    import Textos.ContentFixtures

    @invalid_attrs %{description: nil, location: nil, title: nil, note: nil, media_type: nil, collected_by: nil, old_filename: nil, translated_esp: nil, speakers: nil, translated_eng: nil, recorded_at: nil, record_dated: nil}

    test "list_media/0 returns all media" do
      media = media_fixture()
      assert Content.list_media() == [media]
    end

    test "get_media!/1 returns the media with given id" do
      media = media_fixture()
      assert Content.get_media!(media.id) == media
    end

    test "create_media/1 with valid data creates a media" do
      valid_attrs = %{description: "some description", location: "some location", title: "some title", note: "some note", media_type: "some media_type", collected_by: "some collected_by", old_filename: "some old_filename", translated_esp: true, speakers: ["option1", "option2"], translated_eng: true, recorded_at: ~U[2023-07-28 01:42:00Z], record_dated: true}

      assert {:ok, %Media{} = media} = Content.create_media(valid_attrs)
      assert media.description == "some description"
      assert media.location == "some location"
      assert media.title == "some title"
      assert media.note == "some note"
      assert media.media_type == "some media_type"
      assert media.collected_by == "some collected_by"
      assert media.old_filename == "some old_filename"
      assert media.translated_esp == true
      assert media.speakers == ["option1", "option2"]
      assert media.translated_eng == true
      assert media.recorded_at == ~U[2023-07-28 01:42:00Z]
      assert media.record_dated == true
    end

    test "create_media/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Content.create_media(@invalid_attrs)
    end

    test "update_media/2 with valid data updates the media" do
      media = media_fixture()
      update_attrs = %{description: "some updated description", location: "some updated location", title: "some updated title", note: "some updated note", media_type: "some updated media_type", collected_by: "some updated collected_by", old_filename: "some updated old_filename", translated_esp: false, speakers: ["option1"], translated_eng: false, recorded_at: ~U[2023-07-29 01:42:00Z], record_dated: false}

      assert {:ok, %Media{} = media} = Content.update_media(media, update_attrs)
      assert media.description == "some updated description"
      assert media.location == "some updated location"
      assert media.title == "some updated title"
      assert media.note == "some updated note"
      assert media.media_type == "some updated media_type"
      assert media.collected_by == "some updated collected_by"
      assert media.old_filename == "some updated old_filename"
      assert media.translated_esp == false
      assert media.speakers == ["option1"]
      assert media.translated_eng == false
      assert media.recorded_at == ~U[2023-07-29 01:42:00Z]
      assert media.record_dated == false
    end

    test "update_media/2 with invalid data returns error changeset" do
      media = media_fixture()
      assert {:error, %Ecto.Changeset{}} = Content.update_media(media, @invalid_attrs)
      assert media == Content.get_media!(media.id)
    end

    test "delete_media/1 deletes the media" do
      media = media_fixture()
      assert {:ok, %Media{}} = Content.delete_media(media)
      assert_raise Ecto.NoResultsError, fn -> Content.get_media!(media.id) end
    end

    test "change_media/1 returns a media changeset" do
      media = media_fixture()
      assert %Ecto.Changeset{} = Content.change_media(media)
    end
  end

  describe "subtitles" do
    alias Textos.Content.Subtitle

    import Textos.ContentFixtures

    @invalid_attrs %{complete: nil, format: nil, language: nil, note: nil, final_draft: nil, subtitle_text: nil, subtitler: nil, editors: nil}

    test "list_subtitles/0 returns all subtitles" do
      subtitle = subtitle_fixture()
      assert Content.list_subtitles() == [subtitle]
    end

    test "get_subtitle!/1 returns the subtitle with given id" do
      subtitle = subtitle_fixture()
      assert Content.get_subtitle!(subtitle.id) == subtitle
    end

    test "create_subtitle/1 with valid data creates a subtitle" do
      valid_attrs = %{complete: true, format: "some format", language: "some language", note: "some note", final_draft: true, subtitle_text: "some subtitle_text", subtitler: "some subtitler", editors: ["option1", "option2"]}

      assert {:ok, %Subtitle{} = subtitle} = Content.create_subtitle(valid_attrs)
      assert subtitle.complete == true
      assert subtitle.format == "some format"
      assert subtitle.language == "some language"
      assert subtitle.note == "some note"
      assert subtitle.final_draft == true
      assert subtitle.subtitle_text == "some subtitle_text"
      assert subtitle.subtitler == "some subtitler"
      assert subtitle.editors == ["option1", "option2"]
    end

    test "create_subtitle/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Content.create_subtitle(@invalid_attrs)
    end

    test "update_subtitle/2 with valid data updates the subtitle" do
      subtitle = subtitle_fixture()
      update_attrs = %{complete: false, format: "some updated format", language: "some updated language", note: "some updated note", final_draft: false, subtitle_text: "some updated subtitle_text", subtitler: "some updated subtitler", editors: ["option1"]}

      assert {:ok, %Subtitle{} = subtitle} = Content.update_subtitle(subtitle, update_attrs)
      assert subtitle.complete == false
      assert subtitle.format == "some updated format"
      assert subtitle.language == "some updated language"
      assert subtitle.note == "some updated note"
      assert subtitle.final_draft == false
      assert subtitle.subtitle_text == "some updated subtitle_text"
      assert subtitle.subtitler == "some updated subtitler"
      assert subtitle.editors == ["option1"]
    end

    test "update_subtitle/2 with invalid data returns error changeset" do
      subtitle = subtitle_fixture()
      assert {:error, %Ecto.Changeset{}} = Content.update_subtitle(subtitle, @invalid_attrs)
      assert subtitle == Content.get_subtitle!(subtitle.id)
    end

    test "delete_subtitle/1 deletes the subtitle" do
      subtitle = subtitle_fixture()
      assert {:ok, %Subtitle{}} = Content.delete_subtitle(subtitle)
      assert_raise Ecto.NoResultsError, fn -> Content.get_subtitle!(subtitle.id) end
    end

    test "change_subtitle/1 returns a subtitle changeset" do
      subtitle = subtitle_fixture()
      assert %Ecto.Changeset{} = Content.change_subtitle(subtitle)
    end
  end

  describe "transcriptions" do
    alias Textos.Content.Transcription

    import Textos.ContentFixtures

    @invalid_attrs %{complete: nil, note: nil, final_draft: nil, transcription_text: nil, transcriber: nil, editors: nil}

    test "list_transcriptions/0 returns all transcriptions" do
      transcription = transcription_fixture()
      assert Content.list_transcriptions() == [transcription]
    end

    test "get_transcription!/1 returns the transcription with given id" do
      transcription = transcription_fixture()
      assert Content.get_transcription!(transcription.id) == transcription
    end

    test "create_transcription/1 with valid data creates a transcription" do
      valid_attrs = %{complete: true, note: "some note", final_draft: true, transcription_text: "some transcription_text", transcriber: "some transcriber", editors: ["option1", "option2"]}

      assert {:ok, %Transcription{} = transcription} = Content.create_transcription(valid_attrs)
      assert transcription.complete == true
      assert transcription.note == "some note"
      assert transcription.final_draft == true
      assert transcription.transcription_text == "some transcription_text"
      assert transcription.transcriber == "some transcriber"
      assert transcription.editors == ["option1", "option2"]
    end

    test "create_transcription/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Content.create_transcription(@invalid_attrs)
    end

    test "update_transcription/2 with valid data updates the transcription" do
      transcription = transcription_fixture()
      update_attrs = %{complete: false, note: "some updated note", final_draft: false, transcription_text: "some updated transcription_text", transcriber: "some updated transcriber", editors: ["option1"]}

      assert {:ok, %Transcription{} = transcription} = Content.update_transcription(transcription, update_attrs)
      assert transcription.complete == false
      assert transcription.note == "some updated note"
      assert transcription.final_draft == false
      assert transcription.transcription_text == "some updated transcription_text"
      assert transcription.transcriber == "some updated transcriber"
      assert transcription.editors == ["option1"]
    end

    test "update_transcription/2 with invalid data returns error changeset" do
      transcription = transcription_fixture()
      assert {:error, %Ecto.Changeset{}} = Content.update_transcription(transcription, @invalid_attrs)
      assert transcription == Content.get_transcription!(transcription.id)
    end

    test "delete_transcription/1 deletes the transcription" do
      transcription = transcription_fixture()
      assert {:ok, %Transcription{}} = Content.delete_transcription(transcription)
      assert_raise Ecto.NoResultsError, fn -> Content.get_transcription!(transcription.id) end
    end

    test "change_transcription/1 returns a transcription changeset" do
      transcription = transcription_fixture()
      assert %Ecto.Changeset{} = Content.change_transcription(transcription)
    end
  end

  describe "translations" do
    alias Textos.Content.Translation

    import Textos.ContentFixtures

    @invalid_attrs %{complete: nil, translator: nil, language: nil, note: nil, final_draft: nil, translation_text: nil, editors: nil}

    test "list_translations/0 returns all translations" do
      translation = translation_fixture()
      assert Content.list_translations() == [translation]
    end

    test "get_translation!/1 returns the translation with given id" do
      translation = translation_fixture()
      assert Content.get_translation!(translation.id) == translation
    end

    test "create_translation/1 with valid data creates a translation" do
      valid_attrs = %{complete: true, translator: "some translator", language: "some language", note: "some note", final_draft: true, translation_text: "some translation_text", editors: ["option1", "option2"]}

      assert {:ok, %Translation{} = translation} = Content.create_translation(valid_attrs)
      assert translation.complete == true
      assert translation.translator == "some translator"
      assert translation.language == "some language"
      assert translation.note == "some note"
      assert translation.final_draft == true
      assert translation.translation_text == "some translation_text"
      assert translation.editors == ["option1", "option2"]
    end

    test "create_translation/1 with invalid data returns error changeset" do
      assert {:error, %Ecto.Changeset{}} = Content.create_translation(@invalid_attrs)
    end

    test "update_translation/2 with valid data updates the translation" do
      translation = translation_fixture()
      update_attrs = %{complete: false, translator: "some updated translator", language: "some updated language", note: "some updated note", final_draft: false, translation_text: "some updated translation_text", editors: ["option1"]}

      assert {:ok, %Translation{} = translation} = Content.update_translation(translation, update_attrs)
      assert translation.complete == false
      assert translation.translator == "some updated translator"
      assert translation.language == "some updated language"
      assert translation.note == "some updated note"
      assert translation.final_draft == false
      assert translation.translation_text == "some updated translation_text"
      assert translation.editors == ["option1"]
    end

    test "update_translation/2 with invalid data returns error changeset" do
      translation = translation_fixture()
      assert {:error, %Ecto.Changeset{}} = Content.update_translation(translation, @invalid_attrs)
      assert translation == Content.get_translation!(translation.id)
    end

    test "delete_translation/1 deletes the translation" do
      translation = translation_fixture()
      assert {:ok, %Translation{}} = Content.delete_translation(translation)
      assert_raise Ecto.NoResultsError, fn -> Content.get_translation!(translation.id) end
    end

    test "change_translation/1 returns a translation changeset" do
      translation = translation_fixture()
      assert %Ecto.Changeset{} = Content.change_translation(translation)
    end
  end
end
